path property
绘制路径(为了向后兼容保留,用于传统路径模式)
Drawing path (retained for backward compatibility, used in traditional path mode)
Implementation
DrawPath path = DrawPath();
绘制路径(为了向后兼容保留,用于传统路径模式)
Drawing path (retained for backward compatibility, used in traditional path mode)
DrawPath path = DrawPath();