SimpleLine constructor
Implementation
SimpleLine({
/// 最小点距离,用于过滤过近的点,减少数据量
///
/// Minimum point distance for filtering points that are too close, reducing data volume
this.minPointDistance = 2.0,
/// 是否使用贝塞尔曲线平滑,默认 true
/// 设置为 true 可以解决快速绘制时的折线感问题
///
/// Whether to use bezier curve smoothing, default true
/// Setting to true resolves the jagged line issue when drawing quickly
this.useBezierCurve = true,
});